# This file was auto-generated by Fern from our API Definition.

from .types import (
    ActionBase,
    ActionParameter,
    ActionRequest,
    ActionResponse,
    ConversationExecutedActionPrecondition,
    ConversationPrecondition,
    ConversationPrecondition_ActionExecuted,
    ConversationPrecondition_Metadata,
    ConversationPrecondition_Tags,
    MetadataPrecondition,
    Precondition,
    PreconditionBase,
    PreconditionGroup,
    PreconditionGroupOperator,
    PreconditionOperator,
    Precondition_Conversation,
    Precondition_Group,
    Precondition_User,
    TagsPrecondition,
)

__all__ = [
    "ActionBase",
    "ActionParameter",
    "ActionRequest",
    "ActionResponse",
    "ConversationExecutedActionPrecondition",
    "ConversationPrecondition",
    "ConversationPrecondition_ActionExecuted",
    "ConversationPrecondition_Metadata",
    "ConversationPrecondition_Tags",
    "MetadataPrecondition",
    "Precondition",
    "PreconditionBase",
    "PreconditionGroup",
    "PreconditionGroupOperator",
    "PreconditionOperator",
    "Precondition_Conversation",
    "Precondition_Group",
    "Precondition_User",
    "TagsPrecondition",
]



# This file was auto-generated by Fern from our API Definition.

import typing

BotConversationMessageType = typing.Union[
    typing.Literal["BOT_RESPONSE", "BOT_SUGGESTION", "ACTION_RESPONSE"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from . import actions, app_settings, commons, conversation, knowledge, translations, triggers, users
from .actions import (
    ActionBase,
    ActionParameter,
    ActionRequest,
    ActionResponse,
    ConversationExecutedActionPrecondition,
    ConversationPrecondition,
    ConversationPrecondition_ActionExecuted,
    ConversationPrecondition_Metadata,
    ConversationPrecondition_Tags,
    MetadataPrecondition,
    Precondition,
    PreconditionBase,
    PreconditionGroup,
    PreconditionGroupOperator,
    PreconditionOperator,
    Precondition_Conversation,
    Precondition_Group,
    Precondition_User,
    TagsPrecondition,
)
from .client import AsyncMavenAGI, MavenAGI
from .commons import (
    AppUser,
    AppUserIdentifier,
    AppUserIdentifyingPropertyType,
    AppUserRequest,
    AppUserResponse,
    BadRequestError,
    EntityId,
    EntityIdBase,
    EntityType,
    ErrorMessage,
    EventTriggerBase,
    EventTriggerResponse,
    EventTriggerType,
    Feedback,
    FeedbackBase,
    FeedbackType,
    NotFoundError,
    ServerError,
    UserData,
    VisibilityType,
)
from .conversation import (
    ActionFormField,
    AskRequest,
    AskStreamActionEvent,
    AskStreamChartEvent,
    AskStreamEndEvent,
    AskStreamMetadataEvent,
    AskStreamStartEvent,
    AskStreamTextEvent,
    Attachment,
    BotActionFormResponse,
    BotActionResponse,
    BotChartResponse,
    BotConversationMessageType,
    BotMessage,
    BotResponse,
    BotResponseMetadata,
    BotResponse_ActionForm,
    BotResponse_ActionResponse,
    BotResponse_Chart,
    BotResponse_Text,
    BotTextResponse,
    Capability,
    CategorizationResponse,
    ChartSpecSchema,
    ConversationAnalysis,
    ConversationBase,
    ConversationMessageBase,
    ConversationMessageRequest,
    ConversationMessageResponse,
    ConversationMessageResponse_Bot,
    ConversationMessageResponse_User,
    ConversationRequest,
    ConversationResponse,
    FeedbackRequest,
    GenerateMavenSuggestionsRequest,
    ResponseConfig,
    ResponseLength,
    Sentiment,
    Source,
    StreamResponse,
    StreamResponse_Action,
    StreamResponse_Chart,
    StreamResponse_End,
    StreamResponse_Metadata,
    StreamResponse_Start,
    StreamResponse_Text,
    SubmitActionFormRequest,
    UserConversationMessageType,
    UserMessage,
    UserMessageAttachment,
    UserMessageBase,
)
from .environment import MavenAGIEnvironment
from .knowledge import (
    BaseKnowledgeDocument,
    KnowledgeBaseProperties,
    KnowledgeBaseRequest,
    KnowledgeBaseResponse,
    KnowledgeBaseType,
    KnowledgeBaseVersion,
    KnowledgeBaseVersionType,
    KnowledgeDocumentContentType,
    KnowledgeDocumentRequest,
    KnowledgeDocumentResponse,
)
from .translations import TranslationRequest, TranslationResponse
from .triggers import EventTriggerRequest
from .version import __version__

__all__ = [
    "ActionBase",
    "ActionFormField",
    "ActionParameter",
    "ActionRequest",
    "ActionResponse",
    "AppUser",
    "AppUserIdentifier",
    "AppUserIdentifyingPropertyType",
    "AppUserRequest",
    "AppUserResponse",
    "AskRequest",
    "AskStreamActionEvent",
    "AskStreamChartEvent",
    "AskStreamEndEvent",
    "AskStreamMetadataEvent",
    "AskStreamStartEvent",
    "AskStreamTextEvent",
    "AsyncMavenAGI",
    "Attachment",
    "BadRequestError",
    "BaseKnowledgeDocument",
    "BotActionFormResponse",
    "BotActionResponse",
    "BotChartResponse",
    "BotConversationMessageType",
    "BotMessage",
    "BotResponse",
    "BotResponseMetadata",
    "BotResponse_ActionForm",
    "BotResponse_ActionResponse",
    "BotResponse_Chart",
    "BotResponse_Text",
    "BotTextResponse",
    "Capability",
    "CategorizationResponse",
    "ChartSpecSchema",
    "ConversationAnalysis",
    "ConversationBase",
    "ConversationExecutedActionPrecondition",
    "ConversationMessageBase",
    "ConversationMessageRequest",
    "ConversationMessageResponse",
    "ConversationMessageResponse_Bot",
    "ConversationMessageResponse_User",
    "ConversationPrecondition",
    "ConversationPrecondition_ActionExecuted",
    "ConversationPrecondition_Metadata",
    "ConversationPrecondition_Tags",
    "ConversationRequest",
    "ConversationResponse",
    "EntityId",
    "EntityIdBase",
    "EntityType",
    "ErrorMessage",
    "EventTriggerBase",
    "EventTriggerRequest",
    "EventTriggerResponse",
    "EventTriggerType",
    "Feedback",
    "FeedbackBase",
    "FeedbackRequest",
    "FeedbackType",
    "GenerateMavenSuggestionsRequest",
    "KnowledgeBaseProperties",
    "KnowledgeBaseRequest",
    "KnowledgeBaseResponse",
    "KnowledgeBaseType",
    "KnowledgeBaseVersion",
    "KnowledgeBaseVersionType",
    "KnowledgeDocumentContentType",
    "KnowledgeDocumentRequest",
    "KnowledgeDocumentResponse",
    "MavenAGI",
    "MavenAGIEnvironment",
    "MetadataPrecondition",
    "NotFoundError",
    "Precondition",
    "PreconditionBase",
    "PreconditionGroup",
    "PreconditionGroupOperator",
    "PreconditionOperator",
    "Precondition_Conversation",
    "Precondition_Group",
    "Precondition_User",
    "ResponseConfig",
    "ResponseLength",
    "Sentiment",
    "ServerError",
    "Source",
    "StreamResponse",
    "StreamResponse_Action",
    "StreamResponse_Chart",
    "StreamResponse_End",
    "StreamResponse_Metadata",
    "StreamResponse_Start",
    "StreamResponse_Text",
    "SubmitActionFormRequest",
    "TagsPrecondition",
    "TranslationRequest",
    "TranslationResponse",
    "UserConversationMessageType",
    "UserData",
    "UserMessage",
    "UserMessageAttachment",
    "UserMessageBase",
    "VisibilityType",
    "__version__",
    "actions",
    "app_settings",
    "commons",
    "conversation",
    "knowledge",
    "translations",
    "triggers",
    "users",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ...core.serialization import FieldMetadata
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class SubmitActionFormRequest(UniversalBaseModel):
    action_form_id: typing_extensions.Annotated[str, FieldMetadata(alias="actionFormId")]
    parameters: typing.Dict[str, typing.Optional[typing.Any]] = pydantic.Field()
    """
    Map of parameter IDs to values provided by the user. All required action fields must be provided.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .action_form_field import ActionFormField
from .ask_request import AskRequest
from .ask_stream_action_event import AskStreamActionEvent
from .ask_stream_chart_event import AskStreamChartEvent
from .ask_stream_end_event import AskStreamEndEvent
from .ask_stream_metadata_event import AskStreamMetadataEvent
from .ask_stream_start_event import AskStreamStartEvent
from .ask_stream_text_event import AskStreamTextEvent
from .attachment import Attachment
from .bot_action_form_response import BotActionFormResponse
from .bot_action_response import BotActionResponse
from .bot_chart_response import BotChartResponse
from .bot_conversation_message_type import BotConversationMessageType
from .bot_message import BotMessage
from .bot_response import (
    BotResponse,
    BotResponse_ActionForm,
    BotResponse_ActionResponse,
    BotResponse_Chart,
    BotResponse_Text,
)
from .bot_response_metadata import BotResponseMetadata
from .bot_text_response import BotTextResponse
from .capability import Capability
from .categorization_response import CategorizationResponse
from .chart_spec_schema import ChartSpecSchema
from .conversation_analysis import ConversationAnalysis
from .conversation_base import ConversationBase
from .conversation_message_base import ConversationMessageBase
from .conversation_message_request import ConversationMessageRequest
from .conversation_message_response import (
    ConversationMessageResponse,
    ConversationMessageResponse_Bot,
    ConversationMessageResponse_User,
)
from .conversation_request import ConversationRequest
from .conversation_response import ConversationResponse
from .feedback_request import FeedbackRequest
from .generate_maven_suggestions_request import GenerateMavenSuggestionsRequest
from .response_config import ResponseConfig
from .response_length import ResponseLength
from .sentiment import Sentiment
from .source import Source
from .stream_response import (
    StreamResponse,
    StreamResponse_Action,
    StreamResponse_Chart,
    StreamResponse_End,
    StreamResponse_Metadata,
    StreamResponse_Start,
    StreamResponse_Text,
)
from .submit_action_form_request import SubmitActionFormRequest
from .user_conversation_message_type import UserConversationMessageType
from .user_message import UserMessage
from .user_message_attachment import UserMessageAttachment
from .user_message_base import UserMessageBase

__all__ = [
    "ActionFormField",
    "AskRequest",
    "AskStreamActionEvent",
    "AskStreamChartEvent",
    "AskStreamEndEvent",
    "AskStreamMetadataEvent",
    "AskStreamStartEvent",
    "AskStreamTextEvent",
    "Attachment",
    "BotActionFormResponse",
    "BotActionResponse",
    "BotChartResponse",
    "BotConversationMessageType",
    "BotMessage",
    "BotResponse",
    "BotResponseMetadata",
    "BotResponse_ActionForm",
    "BotResponse_ActionResponse",
    "BotResponse_Chart",
    "BotResponse_Text",
    "BotTextResponse",
    "Capability",
    "CategorizationResponse",
    "ChartSpecSchema",
    "ConversationAnalysis",
    "ConversationBase",
    "ConversationMessageBase",
    "ConversationMessageRequest",
    "ConversationMessageResponse",
    "ConversationMessageResponse_Bot",
    "ConversationMessageResponse_User",
    "ConversationRequest",
    "ConversationResponse",
    "FeedbackRequest",
    "GenerateMavenSuggestionsRequest",
    "ResponseConfig",
    "ResponseLength",
    "Sentiment",
    "Source",
    "StreamResponse",
    "StreamResponse_Action",
    "StreamResponse_Chart",
    "StreamResponse_End",
    "StreamResponse_Metadata",
    "StreamResponse_Start",
    "StreamResponse_Text",
    "SubmitActionFormRequest",
    "UserConversationMessageType",
    "UserMessage",
    "UserMessageAttachment",
    "UserMessageBase",
]



# This file was auto-generated by Fern from our API Definition.

from .app_user import AppUser
from .app_user_identifier import AppUserIdentifier
from .app_user_identifying_property_type import AppUserIdentifyingPropertyType
from .app_user_request import AppUserRequest
from .app_user_response import AppUserResponse
from .entity_id import EntityId
from .entity_id_base import EntityIdBase
from .entity_type import EntityType
from .error_message import ErrorMessage
from .event_trigger_base import EventTriggerBase
from .event_trigger_response import EventTriggerResponse
from .event_trigger_type import EventTriggerType
from .feedback import Feedback
from .feedback_base import FeedbackBase
from .feedback_type import FeedbackType
from .user_data import UserData
from .visibility_type import VisibilityType

__all__ = [
    "AppUser",
    "AppUserIdentifier",
    "AppUserIdentifyingPropertyType",
    "AppUserRequest",
    "AppUserResponse",
    "EntityId",
    "EntityIdBase",
    "EntityType",
    "ErrorMessage",
    "EventTriggerBase",
    "EventTriggerResponse",
    "EventTriggerType",
    "Feedback",
    "FeedbackBase",
    "FeedbackType",
    "UserData",
    "VisibilityType",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from ...commons.types.entity_id_base import EntityIdBase
from ...core.serialization import FieldMetadata
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class GenerateMavenSuggestionsRequest(UniversalBaseModel):
    conversation_message_ids: typing_extensions.Annotated[
        typing.List[EntityIdBase], FieldMetadata(alias="conversationMessageIds")
    ] = pydantic.Field()
    """
    The message ids to generate a suggested response for. One suggestion will be generated for each message id.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .capability import Capability
import pydantic
import typing_extensions
from ...core.serialization import FieldMetadata
from .response_length import ResponseLength
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ResponseConfig(UniversalBaseModel):
    capabilities: typing.List[Capability] = pydantic.Field()
    """
    List of capabilities supported by the caller. Defaults to everything except charts_highcharts_ts. Note that the forms and images capabilities are not respected at this time.
    """

    is_copilot: typing_extensions.Annotated[bool, FieldMetadata(alias="isCopilot")] = pydantic.Field()
    """
    Whether the response is for an human agent (true) or an end user (false). Defaults to false.
    """

    response_length: typing_extensions.Annotated[ResponseLength, FieldMetadata(alias="responseLength")] = (
        pydantic.Field()
    )
    """
    The desired response length. Defaults to ResponseLength.MEDIUM.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .precondition_operator import PreconditionOperator
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PreconditionBase(UniversalBaseModel):
    operator: typing.Optional[PreconditionOperator] = pydantic.Field(default=None)
    """
    Operator to apply to this precondition
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from .knowledge_base_type import KnowledgeBaseType
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class KnowledgeBaseProperties(UniversalBaseModel):
    name: str = pydantic.Field()
    """
    The name of the knowledge base
    """

    type: KnowledgeBaseType = pydantic.Field()
    """
    The type of the knowledge base. Can not be changed once created.
    """

    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The URL to pull content from for RSS and URL knowledge bases.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...commons.types.feedback_base import FeedbackBase
import typing_extensions
from ...commons.types.entity_id_base import EntityIdBase
from ...core.serialization import FieldMetadata
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class FeedbackRequest(FeedbackBase):
    """
    Examples
    --------
    from mavenagi.commons import EntityIdBase
    from mavenagi.conversation import FeedbackRequest

    FeedbackRequest(
        feedback_id=EntityIdBase(
            reference_id="feedback-0",
        ),
        conversation_id=EntityIdBase(
            reference_id="conversation-0",
        ),
        conversation_message_id=EntityIdBase(
            reference_id="message-1",
        ),
        type="THUMBS_UP",
        text="Great answer!",
    )
    """

    feedback_id: typing_extensions.Annotated[EntityIdBase, FieldMetadata(alias="feedbackId")] = pydantic.Field()
    """
    The ID that uniquely identifies this feedback
    """

    conversation_id: typing_extensions.Annotated[EntityIdBase, FieldMetadata(alias="conversationId")] = pydantic.Field()
    """
    The ID that uniquely identifies the the conversation the feedback is about
    """

    conversation_message_id: typing_extensions.Annotated[EntityIdBase, FieldMetadata(alias="conversationMessageId")] = (
        pydantic.Field()
    )
    """
    The ID that uniquely identifies the message within the conversation the feedback is about
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ...commons.types.entity_id import EntityId
from ...core.serialization import FieldMetadata
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class BotActionResponse(UniversalBaseModel):
    """
    A response from an action that was provided to the LLM. Should not be shown to users.
    """

    action_id: typing_extensions.Annotated[EntityId, FieldMetadata(alias="actionId")]
    action_parameters: typing_extensions.Annotated[
        typing.Dict[str, typing.Optional[typing.Any]], FieldMetadata(alias="actionParameters")
    ]
    action_response: typing_extensions.Annotated[str, FieldMetadata(alias="actionResponse")]
    auto_action: typing_extensions.Annotated[bool, FieldMetadata(alias="autoAction")] = pydantic.Field()
    """
    True if the bot automatically took this action. False if the user manually submitted the actionForm.
    """

    action_error: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="actionError")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ActionFormField,
    AskRequest,
    AskStreamActionEvent,
    AskStreamChartEvent,
    AskStreamEndEvent,
    AskStreamMetadataEvent,
    AskStreamStartEvent,
    AskStreamTextEvent,
    Attachment,
    BotActionFormResponse,
    BotActionResponse,
    BotChartResponse,
    BotConversationMessageType,
    BotMessage,
    BotResponse,
    BotResponseMetadata,
    BotResponse_ActionForm,
    BotResponse_ActionResponse,
    BotResponse_Chart,
    BotResponse_Text,
    BotTextResponse,
    Capability,
    CategorizationResponse,
    ChartSpecSchema,
    ConversationAnalysis,
    ConversationBase,
    ConversationMessageBase,
    ConversationMessageRequest,
    ConversationMessageResponse,
    ConversationMessageResponse_Bot,
    ConversationMessageResponse_User,
    ConversationRequest,
    ConversationResponse,
    FeedbackRequest,
    GenerateMavenSuggestionsRequest,
    ResponseConfig,
    ResponseLength,
    Sentiment,
    Source,
    StreamResponse,
    StreamResponse_Action,
    StreamResponse_Chart,
    StreamResponse_End,
    StreamResponse_Metadata,
    StreamResponse_Start,
    StreamResponse_Text,
    SubmitActionFormRequest,
    UserConversationMessageType,
    UserMessage,
    UserMessageAttachment,
    UserMessageBase,
)

__all__ = [
    "ActionFormField",
    "AskRequest",
    "AskStreamActionEvent",
    "AskStreamChartEvent",
    "AskStreamEndEvent",
    "AskStreamMetadataEvent",
    "AskStreamStartEvent",
    "AskStreamTextEvent",
    "Attachment",
    "BotActionFormResponse",
    "BotActionResponse",
    "BotChartResponse",
    "BotConversationMessageType",
    "BotMessage",
    "BotResponse",
    "BotResponseMetadata",
    "BotResponse_ActionForm",
    "BotResponse_ActionResponse",
    "BotResponse_Chart",
    "BotResponse_Text",
    "BotTextResponse",
    "Capability",
    "CategorizationResponse",
    "ChartSpecSchema",
    "ConversationAnalysis",
    "ConversationBase",
    "ConversationMessageBase",
    "ConversationMessageRequest",
    "ConversationMessageResponse",
    "ConversationMessageResponse_Bot",
    "ConversationMessageResponse_User",
    "ConversationRequest",
    "ConversationResponse",
    "FeedbackRequest",
    "GenerateMavenSuggestionsRequest",
    "ResponseConfig",
    "ResponseLength",
    "Sentiment",
    "Source",
    "StreamResponse",
    "StreamResponse_Action",
    "StreamResponse_Chart",
    "StreamResponse_End",
    "StreamResponse_Metadata",
    "StreamResponse_Start",
    "StreamResponse_Text",
    "SubmitActionFormRequest",
    "UserConversationMessageType",
    "UserMessage",
    "UserMessageAttachment",
    "UserMessageBase",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ...commons.types.entity_id_base import EntityIdBase
from ...core.serialization import FieldMetadata
import pydantic
import typing
from .attachment import Attachment
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class AskRequest(UniversalBaseModel):
    """
    Examples
    --------
    from mavenagi.commons import EntityIdBase
    from mavenagi.conversation import AskRequest, Attachment

    AskRequest(
        conversation_message_id=EntityIdBase(
            reference_id="message-0",
        ),
        user_id=EntityIdBase(
            reference_id="user-0",
        ),
        text="How do I reset my password?",
        attachments=[
            Attachment(
                type="image/png",
                content="iVBORw0KGgo...",
            )
        ],
    )
    """

    conversation_message_id: typing_extensions.Annotated[EntityIdBase, FieldMetadata(alias="conversationMessageId")] = (
        pydantic.Field()
    )
    """
    Externally supplied ID to uniquely identify this message within the conversation
    """

    user_id: typing_extensions.Annotated[EntityIdBase, FieldMetadata(alias="userId")] = pydantic.Field()
    """
    Externally supplied ID to uniquely identify the user that created this message
    """

    text: str = pydantic.Field()
    """
    The text of the message
    """

    attachments: typing.Optional[typing.List[Attachment]] = pydantic.Field(default=None)
    """
    The attachments to the message.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    AppUser,
    AppUserIdentifier,
    AppUserIdentifyingPropertyType,
    AppUserRequest,
    AppUserResponse,
    EntityId,
    EntityIdBase,
    EntityType,
    ErrorMessage,
    EventTriggerBase,
    EventTriggerResponse,
    EventTriggerType,
    Feedback,
    FeedbackBase,
    FeedbackType,
    UserData,
    VisibilityType,
)
from .errors import BadRequestError, NotFoundError, ServerError

__all__ = [
    "AppUser",
    "AppUserIdentifier",
    "AppUserIdentifyingPropertyType",
    "AppUserRequest",
    "AppUserResponse",
    "BadRequestError",
    "EntityId",
    "EntityIdBase",
    "EntityType",
    "ErrorMessage",
    "EventTriggerBase",
    "EventTriggerResponse",
    "EventTriggerType",
    "Feedback",
    "FeedbackBase",
    "FeedbackType",
    "NotFoundError",
    "ServerError",
    "UserData",
    "VisibilityType",
]



# This file was auto-generated by Fern from our API Definition.

from .action_base import ActionBase
from .action_parameter import ActionParameter
from .action_request import ActionRequest
from .action_response import ActionResponse
from .conversation_executed_action_precondition import ConversationExecutedActionPrecondition
from .conversation_precondition import (
    ConversationPrecondition,
    ConversationPrecondition_ActionExecuted,
    ConversationPrecondition_Metadata,
    ConversationPrecondition_Tags,
)
from .metadata_precondition import MetadataPrecondition
from .precondition import Precondition, Precondition_Conversation, Precondition_Group, Precondition_User
from .precondition_base import PreconditionBase
from .precondition_group import PreconditionGroup
from .precondition_group_operator import PreconditionGroupOperator
from .precondition_operator import PreconditionOperator
from .tags_precondition import TagsPrecondition

__all__ = [
    "ActionBase",
    "ActionParameter",
    "ActionRequest",
    "ActionResponse",
    "ConversationExecutedActionPrecondition",
    "ConversationPrecondition",
    "ConversationPrecondition_ActionExecuted",
    "ConversationPrecondition_Metadata",
    "ConversationPrecondition_Tags",
    "MetadataPrecondition",
    "Precondition",
    "PreconditionBase",
    "PreconditionGroup",
    "PreconditionGroupOperator",
    "PreconditionOperator",
    "Precondition_Conversation",
    "Precondition_Group",
    "Precondition_User",
    "TagsPrecondition",
]
